
0.4.4 (2015-12-15)
##################

Changes since 0.4.3 (2015-12-06).

Bug Fixes
$$$$$$$$$

* fixes `#282 <https://github.com/biocommons/hgvs/issues/282/>`_: preserve position in "identity" variants (e.g., norm(c.123A>A) => c.123= rather than c.=) [`BROKEN: 5e6fd1524204 <https://github.com/biocommons/hgvs/commit/5e6fd1524204>`_]. (Reported by Stephan Pabinger.)
* fixes `#294 <https://github.com/biocommons/hgvs/issues/294/>`_: extend variant type checks in validator [`BROKEN: e28b5a525f6e <https://github.com/biocommons/hgvs/commit/e28b5a525f6e>`_]
* fixes `#292 <https://github.com/biocommons/hgvs/issues/292/>`_: Fix bug in validator when validating m. variants and add tests [`BROKEN: 64e31808a760 <https://github.com/biocommons/hgvs/commit/64e31808a760>`_]

Other Changes
$$$$$$$$$$$$$

* stopgap for `#253 <https://github.com/biocommons/hgvs/issues/253/>`_: issue warning that p. validation is unsupported [`BROKEN: a9bd9ab405bc <https://github.com/biocommons/hgvs/commit/a9bd9ab405bc>`_] (Reported by Ram Srinivasan.)
